import { useState, useEffect } from "react";
import { useRoute, useLocation } from "wouter";
import { useQuery } from "@tanstack/react-query";
import SearchBar from "@/components/listing/SearchBar";
import ListingGrid from "@/components/listing/ListingGrid";
import Pagination from "@/components/common/Pagination";
import { SORT_OPTIONS } from "@/lib/constants";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { AlertTriangle } from "lucide-react";
import { Card, CardContent } from "@/components/ui/card";
import { Button } from "@/components/ui/button";

interface Listing {
  id: number;
  title: string;
  price: number | null;
  description: string;
  location: string;
  createdAt: string;
  isUrgent?: boolean;
  primaryImage?: string | null;
  userId: number;
}

interface Category {
  id: number;
  name: string;
  slug: string;
  icon: string;
  listingCount: number;
}

const ITEMS_PER_PAGE = 12;

const CategoryListings = () => {
  const [, navigate] = useLocation();
  const [match, params] = useRoute<{ slug: string }>("/categories/:slug");
  
  // State for results
  const [currentPage, setCurrentPage] = useState(1);
  const [sortBy, setSortBy] = useState("date-desc");
  
  // Parse sort value
  const [sortField, sortOrder] = sortBy.split("-");
  
  // Fetch category information
  const {
    data: categoryData,
    isLoading: isCategoryLoading,
    error: categoryError,
  } = useQuery<{ category: Category }>({
    queryKey: [`/api/categories/${params?.slug}`],
    enabled: !!params?.slug,
  });
  
  // Fetch listings for this category
  const {
    data: listingsData,
    isLoading: isListingsLoading,
    refetch,
  } = useQuery<{ listings: Listing[]; pagination: any }>({
    queryKey: ['/api/listings', {
      limit: ITEMS_PER_PAGE,
      offset: (currentPage - 1) * ITEMS_PER_PAGE,
      categoryId: categoryData?.category?.id,
      sortBy: sortField,
      sortOrder: sortOrder as 'asc' | 'desc',
    }],
    enabled: !!categoryData?.category?.id,
  });
  
  // Update URL when page or sort changes
  useEffect(() => {
    if (params?.slug) {
      const searchParams = new URLSearchParams();
      searchParams.set("page", currentPage.toString());
      searchParams.set("sort", sortBy);
      navigate(`/categories/${params.slug}?${searchParams.toString()}`);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [currentPage, sortBy, params?.slug]);
  
  // Handle sort change
  const handleSortChange = (value: string) => {
    setSortBy(value);
    setCurrentPage(1); // Reset to first page when sort changes
  };
  
  // Handle page change
  const handlePageChange = (page: number) => {
    setCurrentPage(page);
    window.scrollTo(0, 0);
  };
  
  // Total pages
  const totalPages = listingsData?.pagination?.total
    ? Math.ceil(listingsData.pagination.total / ITEMS_PER_PAGE)
    : 1;
  
  // Loading state
  const isLoading = isCategoryLoading || isListingsLoading;
  
  // Error state
  if (categoryError || (!isCategoryLoading && !categoryData?.category)) {
    return (
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <Card>
          <CardContent className="pt-6 pb-6 text-center">
            <AlertTriangle className="h-12 w-12 text-red-500 mx-auto mb-4" />
            <h2 className="text-2xl font-bold mb-2">Catégorie non trouvée</h2>
            <p className="text-gray-600 mb-4">
              La catégorie que vous recherchez n'existe pas.
            </p>
            <Button onClick={() => navigate("/")}>
              Retour à l'accueil
            </Button>
          </CardContent>
        </Card>
      </div>
    );
  }
  
  return (
    <div className="min-h-screen">
      {/* Search Bar */}
      <SearchBar compact={true} />
      
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        {/* Category Listings */}
        <div className="mb-8">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-bold">
              {isLoading ? "Chargement..." : categoryData?.category?.name}
              {!isLoading && categoryData?.category && (
                <span className="ml-2 text-sm font-normal text-gray-500">
                  ({categoryData.category.listingCount} annonces)
                </span>
              )}
            </h1>
            
            <div className="flex items-center">
              <span className="mr-2 text-sm">Trier par:</span>
              <Select value={sortBy} onValueChange={handleSortChange}>
                <SelectTrigger className="w-[200px]">
                  <SelectValue placeholder="Trier par" />
                </SelectTrigger>
                <SelectContent>
                  {SORT_OPTIONS.map(option => (
                    <SelectItem key={option.value} value={option.value}>
                      {option.label}
                    </SelectItem>
                  ))}
                </SelectContent>
              </Select>
            </div>
          </div>
          
          <ListingGrid
            listings={listingsData?.listings || []}
            loading={isLoading}
            emptyMessage={
              categoryData?.category
                ? `Aucune annonce disponible dans la catégorie ${categoryData.category.name}`
                : "Aucune annonce disponible"
            }
          />
          
          {/* Pagination */}
          {!isLoading && listingsData?.pagination?.total > 0 && (
            <Pagination
              currentPage={currentPage}
              totalPages={totalPages}
              onPageChange={handlePageChange}
            />
          )}
        </div>
      </div>
    </div>
  );
};

export default CategoryListings;
